@@ -36,7 +36,7 @@ class Classification:
                  input_activation='relu',
                  output_activation='sigmoid',
                  optimizer='adam',
-                 metrics=['accuracy'],
+                 metrics=['accuracy',],
                  loss='binary_crossentropy',
                  validation_split=.20,
                  epochs=100,
